==> open-xchange-core_7.2.0.orig.tar.bz2: open-xchange-core-7.2.0/com.hazelcast/src/com/hazelcast/osgi/HzActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.hazelcast.osgi;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * {@link HzActivator} - The activator for Hazelcast bundle.
 * 
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 */
public class HzActivator implements BundleActivator {

    public HzActivator() {
        super();
    }

    @Override
    public void start(final BundleContext context) throws Exception {
        // Check if log4j is enabled
        boolean hasLog4J = false;
        final Bundle[] bundles = context.getBundles();
        for (int i = 0; !hasLog4J && i < bundles.length; i++) {
            hasLog4J = ("org.apache.commons.logging.log4j".equals(bundles[i].getSymbolicName()));
        }
        if (hasLog4J) {
            System.setProperty("hazelcast.logging.type", "log4j");
        }
    }

    @Override
    public void stop(final BundleContext context) throws Exception {
        // Ignore
    }

}

==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.hazelcast/src/com/hazelcast/osgi/HzActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.hazelcast.osgi;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.config.ConfigurationService;

/**
 * {@link HzActivator} - The activator for Hazelcast bundle.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class HzActivator implements BundleActivator {

    private volatile ServiceTracker<ConfigurationService, ConfigurationService> tracker;

    /**
     * Initializes a new {@link HzActivator}.
     */
    public HzActivator() {
        super();
    }

    @Override
    public void start(final BundleContext context) throws Exception {
        final ServiceTrackerCustomizer<ConfigurationService, ConfigurationService> customizer = new ServiceTrackerCustomizer<ConfigurationService, ConfigurationService>() {

            @Override
            public void removedService(ServiceReference<ConfigurationService> reference, ConfigurationService service) {
                context.ungetService(reference);
            }

            @Override
            public void modifiedService(ServiceReference<ConfigurationService> reference, ConfigurationService service) {
                // Ignore
            }

            @Override
            public ConfigurationService addingService(ServiceReference<ConfigurationService> reference) {
                final ConfigurationService configService = context.getService(reference);
                final boolean loggingEnabled = configService.getBoolProperty("com.openexchange.hazelcast.logging.enabled", true);
                if (loggingEnabled) {
                    checkForLog4j(context);
                } else {
                    System.setProperty("hazelcast.logging.type", "none");
                }
                return configService;
            }
        };
        final ServiceTracker<ConfigurationService, ConfigurationService> tracker = new ServiceTracker<ConfigurationService, ConfigurationService>(context, ConfigurationService.class, customizer);
        this.tracker = tracker;
        tracker.open();
    }

    @Override
    public void stop(final BundleContext context) throws Exception {
        final ServiceTracker<ConfigurationService, ConfigurationService> tracker =  this.tracker;
        if (null != tracker) {
            tracker.close();
            this.tracker = null;
        }
    }

    protected void checkForLog4j(final BundleContext context) {
        boolean hasLog4J = false;
        final Bundle[] bundles = context.getBundles();
        for (int i = 0; !hasLog4J && i < bundles.length; i++) {
            hasLog4J = ("org.apache.commons.logging.log4j".equals(bundles[i].getSymbolicName()));
        }
        if (hasLog4J) {
            System.setProperty("hazelcast.logging.type", "log4j");
        }
    }

}
